@@ -10,7 +10,7 @@ use warnings;
 
 # We must do this hackery because `package NAME VER` does not work with _ in VER
 #   https://github.com/Perl/perl5/issues/21499
-our $VERSION = '0.003_001';
+our $VERSION = '0.003_002';
 
 require XSLoader;
 XSLoader::load( __PACKAGE__, $VERSION );
@@ -18,6 +18,11 @@ XSLoader::load( __PACKAGE__, $VERSION );
 # Squash out the _ but only after loading XS
 $VERSION =~ s/_//g;
 
+# Hackery to make warnings::warnif callable from XS, on perls too old to have
+# warnif_at_level
+$^V ge v5.28 or
+   *warnif_trampoline = sub { warnings::warnif(@_); };
+
 =head1 NAME
 
 C<meta> - meta-programming API
@@ -55,6 +60,13 @@ versions. Once a workable API shape has been found, it is hoped that this
 module will eventually become dual-life and shipped as part of Perl core, as
 the implementation for PPC 0022. See the link in the L</SEE ALSO> section.
 
+I<Since version 0.003_002> all the entry-point functions and constructors in
+this module will provoke warnings in the C<meta::experimental> category. They
+can be silenced by
+
+   use meta;
+   no warnings 'meta::experimental';
+
 =cut
 
 =head1 FUNCTIONS
